km3pipe.time.Cuckoo
===================

.. currentmodule:: km3pipe.time

.. autoclass:: Cuckoo

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Cuckoo.__init__
      ~Cuckoo.msg
      ~Cuckoo.reset
   
   

   
   
   